summaryrefslogtreecommitdiffstats
path: root/crawl-ref/source/delay.cc
diff options
context:
space:
mode:
Diffstat (limited to 'crawl-ref/source/delay.cc')
-rw-r--r--crawl-ref/source/delay.cc6
1 files changed, 4 insertions, 2 deletions
diff --git a/crawl-ref/source/delay.cc b/crawl-ref/source/delay.cc
index c08debf08d..0aff7a3d8d 100644
--- a/crawl-ref/source/delay.cc
+++ b/crawl-ref/source/delay.cc
@@ -95,8 +95,10 @@ static int recite_to_monsters(int x, int y, int pow, int unused)
{
resist = mons_resist_magic(mons);
- // much lower chances at influencing demons
- if (holiness == MH_DEMONIC)
+ // much lower chances at influencing undead/demons
+ if (holiness == MH_UNDEAD)
+ pow -= 2 + random2(3);
+ else if (holiness == MH_DEMONIC)
pow -= 3 + random2(5);
}